<?php

namespace App\Http\Controllers;

use App\Models\Diagnostico;
use App\Models\ExamenGinecologo;
use App\Models\ExamenRealizado;
use App\Models\Ginecologia;
use App\Models\InformeFertilidad;
use App\Models\Medico;
use App\Models\Paciente;
use App\Models\PacienteEstado;
use App\Models\PerfilHormonal;
use App\Models\Peticion;
use App\Models\Seguro;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Barryvdh\DomPDF\Facade\Pdf as FacadePdf;
class FertilidadController extends Controller
{


    public function store(Request $request)
    {
        $datos = $request->all();
        $idpaciente = $request->input('idpaciente');
        $visita = $request->input('visita');
        $tipo = $request->input('tipo');
        //Bandera para registrar un nuevo dx
        $editarDx = $request->input('editar-dx');
        //transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);
        $diagnosticoId = $request->input('diagnostico_id');
        // Iniciar la transacción
        DB::beginTransaction();

        try {
            //Actualizamos el seguro
            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();

            //Creamos un nuevo diagnosito de tipo 4 si editarDx es true
            if ($editarDx) {
                if ($diagnosticoId) {
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 6;
                    $diagnostico->save();
                } else {
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 100;
                    $diagnostico->save();
                }
            }

            // Crear y guardar la Peticion
            $peticion = new Peticion();
            $peticion->visita = $visita;
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->idpaciente = $idpaciente;
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            $peticion->tipo = $tipo;
            $peticion->save();

            $estadoPaciente = new PacienteEstado();
            $estadoPaciente->idpeticion = $peticion->id;
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            $ginecologia = new Ginecologia();
            $ginecologia->idpeticion = $peticion->id;
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->save();

            if ($tipo == 6) {
                $examen = new ExamenGinecologo();
                $examen->idginecologia = $ginecologia->id;
                for ($i = 1; $i <= 13; $i++) {
                    $valor = "posicion" . $i;
                    if ($request->$valor == 1) {
                        $examen->$valor = 1;
                    } else {
                        $examen->$valor = 0;
                    }
                }
                $examen->abdomen = $request->input('abdomen');
                $examen->tacto = $request->input('tacto');
                $examen->vulva = $request->input('vulva');
                $examen->cervix = $request->input('cervix');
                $examen->especulo = $request->input('especulo');
                $examen->utero = $request->input('utero');
                $examen->trompas = $request->input('trompas');
                $examen->ovarioder = $request->input('ovarioder');
                $examen->ovarioizq = $request->input('ovarioizq');
                $examen->otros = $request->input('otros');
                $examen->mamader = $request->input('mamader');
                $examen->mamaizq = $request->input('mamaizq');
                $examen->save();

                $informe = new InformeFertilidad();
                $informe->idginecologia = $ginecologia->id;
                $informe->antecedentes_pareja = $request->input('antecedentes_pareja');
                $informe->antecedentes_ginecologicos = $request->input('antecedentes_ginecologicos');
                $informe->cirugias = $request->input('cirugias');
                $informe->convivencia = $request->input('convivencia');
                $informe->busqueda = $request->input('busqueda');
                $informe->factor_f = $request->input('factor_f');
                $informe->factor_m = $request->input('factor_m');
                $informe->observaciones = $request->input('observaciones');
                $informe->save();


                //Registrando los examenes realizados al paciente en ExamenRealizado
                if (isset($datos['fecha_examen'])) {
                    for ($i = 0; $i < count($datos['fecha_examen']); $i++) {
                        $examenRealizado = new ExamenRealizado();
                        $examenRealizado->idpaciente = $idpaciente;
                        $examenRealizado->fecha = $datos['fecha_examen'][$i];
                        $examenRealizado->procedimiento = $datos['procedimiento_examen'][$i];
                        $examenRealizado->medico = $datos['medico_examen'][$i];
                        $examenRealizado->diagnostico = $datos['diagnostico_examen'][$i];
                        $examenRealizado->lugar = $datos['lugar_examen'][$i];
                        $examenRealizado->save();
                    }
                }
                if (isset($datos['hormona'])) {
                    for ($i = 0; $i < count($datos['hormona']); $i++) {
                        $perfilHormonal = new PerfilHormonal();
                        $perfilHormonal->idginecologia = $ginecologia->id;
                        $perfilHormonal->hormona = $datos['hormona'][$i];
                        $perfilHormonal->resultado = $datos['resultado'][$i];
                        $perfilHormonal->valor_normal = $datos['valores'][$i];
                        $perfilHormonal->save();
                    }
                }

            }

            //Confirmar la transaccion
            DB::commit();
            session()->flash('success', 'Informe creado exitosamente.');
            return redirect()->route('fertilidad.show', $peticion->id);
        } catch (\Exception $e) {
            // En caso de error, hacer rollback de la transacción
            DB::rollBack();
            dd($e);

            session()->flash('error', 'Ocurrió un error al crear o actualizar el Destino de Informe: ' . $e->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show(string $id)
    {
        $peticion = Peticion::with('ginecologia', 'paciente', 'pacienteEstado')->find($id);

        $ginecologia = $peticion->ginecologia;
        $fertilidad = $ginecologia->informeFertilidad;
        $examen = $ginecologia->examen;
        $perfilHormonal = $ginecologia->perfilHormonal;
        $paciente = $peticion->paciente;
        $estadoPaciente = $peticion->pacienteEstado;
        $seguros = Seguro::all();
        $medico = Medico::all();

        //filtramos sus diagnosticos
        $diagnosticoFertilidad = $paciente->diagnosticos->where('tipo', 6)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoFertilidad) {
            $paciente->diagnostico_id = $diagnosticoFertilidad->id;
            $paciente->diagnostico = $diagnosticoFertilidad->nombre;
        } else if ($diagnosticoOrigen) {

            $paciente->diagnostico_id = $diagnosticoOrigen->id;
            $paciente->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $paciente->diagnostico_id = null;
            $paciente->diagnostico = null;
        }
        return view('fertilidad.show', compact('id', 'medico', 'estadoPaciente', 'ginecologia', 'paciente', 'seguros', 'fertilidad', 'examen', 'perfilHormonal'));
    }

    public function crearFertilidad($id)
    {
        $medico = DB::table('medicos')->select('medicos.*')->get();
        $paciente = Paciente::find($id);
        $seguros = Seguro::all();
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')->where('pacientes.id', '=', $id)->get();

        $historicoEstado = Peticion::join('paciente_estado', 'paciente_estado.idpeticion', '=', 'peticiones.id')
            ->select('peticiones.visita', 'paciente_estado.*')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 6)
            ->get();

        $diagnosticoGineco = $paciente->diagnosticos->where('tipo', 6)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoGineco) {
            $datos[0]->diagnostico_id = $diagnosticoGineco->id;
            $datos[0]->diagnostico = $diagnosticoGineco->nombre;
        } else if ($diagnosticoOrigen) {

            $datos[0]->diagnostico_id = $diagnosticoOrigen->id;
            $datos[0]->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $datos[0]->diagnostico_id = null;
            $datos[0]->diagnostico = null;
        }
        return view('fertilidad.create', compact('datos', 'id', 'hoy', 'medico', 'historicoEstado', 'paciente', 'seguros'));
    }

    public function editarFertilidad(Request $request, $id)
    {

        $datos = $request->all();
        $idpaciente = $request->input('idpaciente');
        $tipo = $request->input('tipo');

        // Bandera para actualizar un dx
        $editarDx = $request->input('editarDx');
        // Transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);
        $diagnosticoId = $request->input('diagnosticoId');

        // Iniciar la transacción
        DB::beginTransaction();

        try {
            // Actualizamos el seguro
            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();

            // Actualizamos el diagnóstico si editarDx es true
            if ($editarDx) {
                $diagnostico = Diagnostico::find($diagnosticoId);
                if ($diagnostico) {
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 6; // o 100 según la lógica anterior
                    $diagnostico->save();
                } else {
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 100;
                    $diagnostico->save();
                }
            }

            // Actualizar o encontrar la Peticion existente
            $peticion = Peticion::findOrFail($id);
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            $peticion->tipo = $tipo;
            $peticion->save();

            // Actualizar el estado del paciente
            $estadoPaciente = PacienteEstado::where('idpeticion', $peticion->id)->firstOrFail();
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            // Actualizar o crear Ginecologia
            $ginecologia = Ginecologia::where('idpeticion', $peticion->id)->first();
            if (!$ginecologia) {
                $ginecologia = new Ginecologia();
                $ginecologia->idpeticion = $peticion->id;
            }
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->save();

            // Actualizar o crear ExamenGinecologo
            if ($tipo == 6) {
                $examen = ExamenGinecologo::where('idginecologia', $ginecologia->id)->first();
                if (!$examen) {
                    $examen = new ExamenGinecologo();
                    $examen->idginecologia = $ginecologia->id;
                }
                for ($i = 1; $i <= 13; $i++) {
                    $valor = "posicion" . $i;
                    $examen->$valor = $request->$valor == 1 ? 1 : 0;
                }
                $examen->abdomen = $request->input('abdomen');
                $examen->tacto = $request->input('tacto');
                $examen->vulva = $request->input('vulva');
                $examen->cervix = $request->input('cervix');
                $examen->especulo = $request->input('especulo');
                $examen->utero = $request->input('utero');
                $examen->trompas = $request->input('trompas');
                $examen->ovarioder = $request->input('ovarioder');
                $examen->ovarioizq = $request->input('ovarioizq');
                $examen->otros = $request->input('otros');
                $examen->mamader = $request->input('mamader');
                $examen->mamaizq = $request->input('mamaizq');
                $examen->save();

                // Actualizar InformeFertilidad
                $informe = InformeFertilidad::where('idginecologia', $ginecologia->id)->first();
                if (!$informe) {
                    $informe = new InformeFertilidad();
                    $informe->idginecologia = $ginecologia->id;
                }
                $informe->antecedentes_pareja = $request->input('antecedentes_pareja');
                $informe->antecedentes_ginecologicos = $request->input('antecedentes_ginecologicos');
                $informe->cirugias = $request->input('cirugias');
                $informe->convivencia = $request->input('convivencia');
                $informe->busqueda = $request->input('busqueda');
                $informe->factor_f = $request->input('factor_f');
                $informe->factor_m = $request->input('factor_m');
                $informe->observaciones = $request->input('observaciones');
                $informe->save();

                // Actualizar los examenes realizados al paciente en ExamenRealizado
                if (isset($datos['fecha_examen'])) {
                    foreach ($datos['fecha_examen'] as $i => $fecha) {
                        $examenRealizado = ExamenRealizado::where('idpaciente', $idpaciente)
                            ->where('fecha', $fecha)
                            ->first();

                        if (!$examenRealizado) {
                            $examenRealizado = new ExamenRealizado();
                            $examenRealizado->idpaciente = $idpaciente;
                        }
                        $examenRealizado->fecha = $fecha;
                        $examenRealizado->procedimiento = $datos['procedimiento_examen'][$i];
                        $examenRealizado->medico = $datos['medico_examen'][$i];
                        $examenRealizado->diagnostico = $datos['diagnostico_examen'][$i];
                        $examenRealizado->lugar = $datos['lugar_examen'][$i];
                        $examenRealizado->save();
                    }
                }

                if (isset($datos['hormona'])) {
                    foreach ($datos['hormona'] as $i => $hormona) {
                        // Busca en la base de datos un registro de PerfilHormonal que coincida con el id de ginecología y la hormona actual
                        $perfilHormonal = PerfilHormonal::where('idginecologia', $ginecologia->id)
                            ->where('hormona', $hormona)
                            ->first();

                        // Si no se encontró un registro, se crea una nueva instancia de PerfilHormonal
                        if (!$perfilHormonal) {
                            $perfilHormonal = new PerfilHormonal();
                            // Asigna el id de ginecología a la nueva instancia
                            $perfilHormonal->idginecologia = $ginecologia->id;
                        }

                        // Asigna el nombre de la hormona a la instancia de PerfilHormonal
                        $perfilHormonal->hormona = $hormona;
                        // Asigna el resultado correspondiente a la hormona actual desde el array $datos['resultado_hormona']
                        $perfilHormonal->resultado = $datos['resultado'][$i];
                        $perfilHormonal->valor_normal = $datos['valores'][$i];
                        // Guarda el registro en la base de datos (ya sea un nuevo registro o uno existente)
                        $perfilHormonal->save();
                    }
                }

            }

            // Confirmar la transacción
            DB::commit();

            return response()->json(['success' => true]);
        } catch (\Exception $e) {
            // Si ocurre un error, revertir la transacción
            DB::rollBack();
            return response()->json(['success' => false, 'error' => $e->getMessage()]);
        }
    }

    public function historialInformacionFertilidad($id)
    {
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->where('pacientes.id', '=', $id)->get();
        return view('fertilidad.resultadosHistorial', compact('datos', 'id', 'hoy'));
    }

    public function eliminarPerfilHormonal($id)
    {
        $perfilHormonal = PerfilHormonal::find($id);
        $perfilHormonal->delete();
        return response()->json(['success' => 'Perfil hormonal eliminado correctamente.']);
    }

    public function actualizarPerfilHormonal(Request $request, $id)
    {

        //el campo a editar
        $field = $request->input('field');
        //el valor
        $valor = $request->input('value');
        $perfilHormonal = PerfilHormonal::find($id);
        $perfilHormonal->$field = $valor;
        $perfilHormonal->save();
        return response()->json(['success' => 'Perfil hormonal actualizado correctamente.']);
    }

    public function actualizarExamen(Request $request, $id)
    {
        //el campo a editar
        $field = $request->input('field');
        //el valor
        $valor = $request->input('value');
        $examen = ExamenRealizado::find($id);
        $examen->$field = $valor;
        $examen->save();
    }
    public function eliminarExamen($id)
    {
        $examen = ExamenRealizado::find($id);
        $examen->delete();
        return response()->json(['success' => 'Examen eliminado correctamente.']);
    }

    public function fertilidadPdf($id)
    {
        $peticion = Peticion::with('ginecologia', 'paciente', 'pacienteEstado')->find($id);
        $ginecologia = $peticion->ginecologia;
        $fertilidad = $ginecologia->informeFertilidad;
        $examen = $ginecologia->examen;
        $perfilHormonal = $ginecologia->perfilHormonal;
        $paciente = $peticion->paciente;
        $pareja = $paciente->pareja;
        $estadoPaciente = $peticion->pacienteEstado;
        //obtener al medi en la pos [0]
        $medico = Medico::first();
        //filtramos sus diagnosticos
        $diagnosticoFertilidad = $paciente->diagnosticos->where('tipo', 6)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoFertilidad) {
            $paciente->diagnostico_id = $diagnosticoFertilidad->id;
            $paciente->diagnostico = $diagnosticoFertilidad->nombre;
        } else if ($diagnosticoOrigen) {

            $paciente->diagnostico_id = $diagnosticoOrigen->id;
            $paciente->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $paciente->diagnostico_id = null;
            $paciente->diagnostico = null;
        }
        //return response()->json($datosPaciente);
        //--------------------------------------GENERAR QR--------------------
        $nombrePdf = 'Fertilidad_' . $paciente->paterno . " " . $paciente->materno . " " . $paciente->nombre;
        $enlace = 'https://data-net-lab.com/ginecologia/public/fertilidadPdf/' . $id;

        $qrCodePath = '../public/qrcodes/' . $id . '.png';
        // Verificar si el código QR ya existe
        if (!file_exists($qrCodePath)) {
            // Generar el código QR solo si no existe
            QrCode::format('png')->size(450)->generate($enlace . $id, $qrCodePath);
        }
        // Asignar el ID del código QR
        $codigoqr = $id;

        //Formateamos y agregamos dias a la FUM de la paciente
        if ($ginecologia->fum) {
            $fum = \Carbon\Carbon::parse($ginecologia->fum);
            $formatedFum = $fum->format('d/m/Y');

            // Verificamos si han pasado menos de 10 meses
            if ($fum->diffInMonths(\Carbon\Carbon::now()) < 10) {
                $daysDiff = $fum->diffInDays(\Carbon\Carbon::now());
                $formatedFum .= " y $daysDiff días";
            }
            // Asignamos el resultado al objeto
            $ginecologia->fum = $formatedFum;
        }
        // Cargar la vista y pasar los datos
        $pdf = FacadePdf::loadView('fertilidad.fertilidadPdf', compact('medico', 'paciente', 'codigoqr', 'ginecologia', 'estadoPaciente', 'fertilidad', 'pareja', 'examen', 'perfilHormonal','peticion'))->setPaper('letter', 'portrait');
        // Descargar el PDF con un nombre específico
        $nombreArchivo = $nombrePdf . '.pdf';
        return $pdf->stream($nombreArchivo);
    }

    public function obtenerHistorialFertilidad($id)
    {
        $data = DB::table('peticiones')
            ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
            ->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 6)
            ->select('peticiones.*', 'institucion.nombreInstituto')
            ->orderBy('peticiones.visita', 'DESC')
            ->get();
        return response()->json($data);
    }
}
