<?php

namespace App\Http\Controllers;

use App\Models\Diagnostico;
use App\Models\ExamenGinecologo;
use App\Models\Ginecologia;
use App\Models\InformeGinecologia;
use App\Models\Institucion;
use App\Models\Medico;
use App\Models\Paciente;
use App\Models\PacienteEstado;
use App\Models\Peticion;
use App\Models\Seguro;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Barryvdh\DomPDF\Facade\Pdf as FacadePdf;

class GinecologiaController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        $imagenes = $request->validate([
            'imagen1' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Máximo 2 MB
            'imagen2' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Opcional
        ]);
        //return response()->json($request);
        $idpaciente = $request->input('idpaciente');
        $registro = $request->input('registro');
        $visita = $request->input('visita');
        $tipo = $request->input('tipo');
        $remitente = $request->input('remitente');
        //Bandera para registrar un nuevo dx
        $editarDx = $request->input('editar-dx');
        //transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);
        $diagnosticoId = $request->input('diagnostico_id');
        // Iniciar la transacción
        DB::beginTransaction();

        try {
            //Actualizamos el seguro
            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();

            //Creamos un nuevo diagnosito de tipo 4 si editarDx es true
            if ($editarDx) {
                if ($diagnosticoId) {
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 4;
                    $diagnostico->save();
                } else {
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 100;
                    $diagnostico->save();
                }
            }

            // Crear y guardar la Peticion
            $peticion = new Peticion();
            $peticion->registro = $registro;
            $peticion->visita = $visita;
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->idpaciente = $idpaciente;
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            $peticion->remitente = $remitente;
            $peticion->tipo = $tipo;
            $peticion->save();

            $estadoPaciente = new PacienteEstado();
            $estadoPaciente->idpeticion = $peticion->id;
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            $ginecologia = new Ginecologia();
            $ginecologia->idpeticion = $peticion->id;
            $ginecologia->motivo = $request->input('motivo');
            $ginecologia->enfermedad = $request->input('enfermedad');
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->conclusion = $request->input('conclusion');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->descripcion_imagenes = $request->input('descripcion_imagenes');

            //Agregamos imagenes en cacso de que lo envien
            if ($imagenes) {
                //Guardar cuando hay algo en imagen1
                if (isset($imagenes['imagen1'])) {
                    $imagen1 = $imagenes['imagen1'];
                    $nombreImagen1 = time() . '_' . $imagen1->getClientOriginalName();
                    $imagen1->move(public_path('images'), $nombreImagen1);
                    $ginecologia->imagen1 = $nombreImagen1;
                }
                if (isset($imagenes['imagen2'])) {
                    $imagen2 = $imagenes['imagen2'];
                    $nombreImagen2 = time() . '_' . $imagen2->getClientOriginalName();
                    $imagen2->move(public_path('images'), $nombreImagen2);
                    $ginecologia->imagen2 = $nombreImagen2;
                }
            }
            $ginecologia->save();
            if ($tipo == 4) {
                $examen = new ExamenGinecologo();
                $examen->idginecologia = $ginecologia->id;
                for ($i = 1; $i <= 13; $i++) {
                    $valor = "posicion" . $i;
                    if ($request->$valor == 1) {
                        $examen->$valor = 1;
                    } else {
                        $examen->$valor = 0;
                    }
                }


                $examen->abdomen = $request->input('abdomen');
                $examen->tacto = $request->input('tacto');
                $examen->vulva = $request->input('vulva');
                $examen->cervix = $request->input('cervix');
                $examen->especulo = $request->input('especulo');
                $examen->utero = $request->input('utero');
                $examen->trompas = $request->input('trompas');
                $examen->ovarioder = $request->input('ovarioder');
                $examen->ovarioizq = $request->input('ovarioizq');
                $examen->otros = $request->input('otros');

                $examen->mamader = $request->input('mamader');
                $examen->mamaizq = $request->input('mamaizq');
                $examen->save();

                $informe = new InformeGinecologia();
                $informe->idginecologia = $ginecologia->id;
                //Para las posiciones de mama
                for ($i = 1; $i <= 8; $i++) {
                    $valor = "mama" . $i;
                    if ($request->$valor == 1) {
                        $informe->$valor = 1;
                    } else {
                        $informe->$valor = 0;
                    }
                }
                $informe->imprimir = $request->input('imprimir');
                $informe->save();
            }
            // Confirmar la transacción
            DB::commit();
            session()->flash('success', 'Destino de Informe creado exitosamente.');
            return redirect()->route('ginecologias.show', $peticion->id);
        } catch (\Exception $e) {
            // En caso de error, hacer rollback de la transacción
            DB::rollBack();
            dd($e);

            session()->flash('error', 'Ocurrió un error al crear o actualizar el Destino de Informe: ' . $e->getMessage());
            return redirect()->back()->withInput();
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $datos = DB::table('peticiones')
            ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
            ->where('peticiones.id', $id)
            ->select('peticiones.*', 'pacientes.*')
            ->get();
        $paciente = Paciente::find($datos[0]->idpaciente);
        $seguros = Seguro::all();
        $estadoPaciente = PacienteEstado::where('idpeticion', $id)->get();
        $datosGinecologia = Ginecologia::with('informe')->where('idpeticion', $id)->get();
        $examen = Ginecologia::join('examen_ginecologo', 'examen_ginecologo.idginecologia', '=', 'ginecologia.id')
            ->where('ginecologia.idpeticion', $id)
            ->get();
        //return response()->json($examen);
        $medico = Medico::all();
        //filtramos sus diagnosticos
        $diagnosticoGineco = $paciente->diagnosticos->where('tipo', 4)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoGineco) {
            $datos[0]->diagnostico_id = $diagnosticoGineco->id;
            $datos[0]->diagnostico = $diagnosticoGineco->nombre;
        } else if ($diagnosticoOrigen) {

            $datos[0]->diagnostico_id = $diagnosticoOrigen->id;
            $datos[0]->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $datos[0]->diagnostico_id = null;
            $datos[0]->diagnostico = null;
        }

        return view('ginecologia.show', compact('datos', 'id', 'medico', 'estadoPaciente', 'datosGinecologia', 'examen', 'paciente', 'seguros'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
    public function obtenerHistorialGinecologia($id)
    {
        $data = DB::table('peticiones')
            ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
            ->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 4)
            ->select('peticiones.*', 'institucion.nombreInstituto')
            ->orderBy('peticiones.visita', 'DESC')
            ->get();
        return response()->json($data);
    }
    public function crearGinecologia($id)
    {
        $paciente = Paciente::find($id);
        $seguros = Seguro::all();
        $medico = DB::table('medicos')->select('medicos.*')->get();
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')->where('pacientes.id', '=', $id)->get();
        $historicoEstado = Peticion::join('paciente_estado', 'paciente_estado.idpeticion', '=', 'peticiones.id')
            ->select('peticiones.visita', 'paciente_estado.*')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 4)
            ->get();
        //return response()->json($medico);

        //filtramos sus diagnosticos
        $diagnosticoGineco = $paciente->diagnosticos->where('tipo', 4)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoGineco) {
            $datos[0]->diagnostico_id = $diagnosticoGineco->id;
            $datos[0]->diagnostico = $diagnosticoGineco->nombre;
        } else if ($diagnosticoOrigen) {
            $datos[0]->diagnostico_id = $diagnosticoOrigen->id;
            $datos[0]->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $datos[0]->diagnostico_id = null;
            $datos[0]->diagnostico = null;
        }
        return view('ginecologia.create', compact('datos', 'id', 'hoy', 'medico', 'historicoEstado', 'paciente', 'seguros'));
    }
    public function obtenerHistorialEstado($id, Request $request)
    {

        $tipo = $request->input('tipo');
        $data = Peticion::join('paciente_estado', 'paciente_estado.idpeticion', '=', 'peticiones.id')
            ->select('peticiones.visita', 'paciente_estado.*')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', $tipo)
            ->get();
        return response()->json($data);
    }

    public function historialInformacionGinecologia($id)
    {
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->where('pacientes.id', '=', $id)->get();

        return view('ginecologia.resultadosHistorial', compact('datos', 'id', 'hoy'));
    }
    public function editarGinecologia(Request $request, string $id)
    {
        //return response()->json($request);
        $imagenes = $request->validate([
            'imagen1' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Máximo 2 MB
            'imagen2' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Opcional
        ]);
        $idpaciente = $request->input('idpaciente');
        $visita = $request->input('visita');
        $tipo = $request->input('tipo');

        $editarDx = $request->input('editarDx');
        $diagnostico_id = $request->input('diagnosticoId');
        //transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);
        //$remitente = $request->input('remitente');
        // Iniciar la transacción
        DB::beginTransaction();

        try {
            //Del paciente
            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();

            //Editar el diagnostico del informe
            if ($editarDx) {
                //buscamos el diagnostico y le cambiamos el nombre
                if ($diagnostico_id) {
                    $diagnostico = Diagnostico::where('id', $diagnostico_id)->firstOrFail();
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->save();
                } else {
                    Diagnostico::create([
                        'idpaciente' => $idpaciente,
                        'nombre' => $request->input('diagnostico'),
                        'tipo' => 100,
                    ]);
                }
            }
            // Actualizar
            $peticion = Peticion::where('id', $id)->firstOrFail();
            $peticion->visita = $visita;
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->idpaciente = $idpaciente;
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            //$peticion->remitente = $remitente;
            $peticion->tipo = $tipo;
            $peticion->save();

            $estadoPaciente = PacienteEstado::where('idpeticion', $id)->firstOrFail();
            $estadoPaciente->idpeticion = $peticion->id;
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            $ginecologia = Ginecologia::where('idpeticion', $id)->firstOrFail();
            $ginecologia->idpeticion = $peticion->id;
            $ginecologia->motivo = $request->input('motivo');
            $ginecologia->enfermedad = $request->input('enfermedad');
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->conclusion = $request->input('conclusion');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->descripcion_imagenes = $request->input('descripcion_imagenes');
            //Agregamos imagenes en cacso de que lo envien
            if ($imagenes) {
                //Guardar cuando hay algo en imagen1
                if ($request->hasFile('imagen1')) {
                    $imagen1 = $request->file('imagen1');
                    //Si el informe ya tiene una imagen1 tomamos el anterior, de lo contrario generamos nuevo nombre
                    $nombreImagen1 = $ginecologia->imagen1 ? $ginecologia->imagen1 : time() . '_' . $imagen1->getClientOriginalName();
                    $imagen1->move(public_path('images'), $nombreImagen1);
                    $ginecologia->imagen1 = $nombreImagen1;
                }
                if ($request->hasFile('imagen2')) {
                    $imagen2 = $request->file('imagen2');
                    $nombreImagen2 = $ginecologia->imagen2 ? $ginecologia->imagen2 : time() . '_' . $imagen2->getClientOriginalName();
                    $imagen2->move(public_path('images'), $nombreImagen2);
                    $ginecologia->imagen2 = $nombreImagen2;
                }
            }
            $ginecologia->save();
            if ($tipo == 4) {
                $examen = ExamenGinecologo::where('idginecologia', $ginecologia->id)->firstOrFail();
                $examen->idginecologia = $ginecologia->id;
                for ($i = 1; $i <= 13; $i++) {
                    $valor = "posicion" . $i;
                    if ($request->$valor == 1) {
                        $examen->$valor = 1;
                    } else {
                        $examen->$valor = 0;
                    }
                }

                $examen->abdomen = $request->input('abdomen');
                $examen->tacto = $request->input('tacto');
                $examen->vulva = $request->input('vulva');
                $examen->cervix = $request->input('cervix');
                $examen->especulo = $request->input('especulo');
                $examen->utero = $request->input('utero');
                $examen->trompas = $request->input('trompas');
                $examen->ovarioder = $request->input('ovarioder');
                $examen->ovarioizq = $request->input('ovarioizq');
                $examen->otros = $request->input('otros');
                $examen->mamader = $request->input('mamader');
                $examen->mamaizq = $request->input('mamaizq');
                $examen->save();
                $informe = InformeGinecologia::where('idginecologia', $ginecologia->id)->firstOrFail();
                //Para las posiciones de mama
                //Para posiciones de mama
                for ($i = 1; $i <= 8; $i++) {
                    $valor = "mama" . $i;
                    if ($request->$valor == 1) {
                        $informe->$valor = 1;
                    } else {
                        $informe->$valor = 0;
                    }
                }
                $informe->imprimir = $request->input('imprimir');
                $informe->save();
            }
            // Confirmar la transacción
            DB::commit();

            return response()->json(['message' => 'Registro actualizado correctamente'], 200);
        } catch (\Exception $e) {
            // En caso de error, hacer rollback de la transacción
            DB::rollBack();
            return response()->json(['error' => 'Error al editar el registro: ' . $e->getMessage()], 500);
        }
    }


    public function ginecologiaPdf($id)
    {

        $peticion = Peticion::with('ginecologia', 'paciente', 'pacienteEstado')->find($id);
        $ginecologia = $peticion->ginecologia;
        $examen = $ginecologia->examen;
        $perfilHormonal = $ginecologia->perfilHormonal;
        $paciente = $peticion->paciente;
        $pareja = $paciente->pareja;
        $estadoPaciente = $peticion->pacienteEstado;
        $seguros = Seguro::all();
        //obtener al medi en la pos [0]
        $medico = Medico::first();
        //filtramos su diagnostico
        $diagnosticoFertilidad = $paciente->diagnosticos->where('tipo', 4)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoFertilidad) {
            $paciente->diagnostico_id = $diagnosticoFertilidad->id;
            $paciente->diagnostico = $diagnosticoFertilidad->nombre;
        } else if ($diagnosticoOrigen) {

            $paciente->diagnostico_id = $diagnosticoOrigen->id;
            $paciente->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $paciente->diagnostico_id = null;
            $paciente->diagnostico = null;
        }
        $estadoPaciente = PacienteEstado::where('idpeticion', $id)->get();
        $datosGinecologia = Ginecologia::with('informe')->where('idpeticion', $id)->get();
        $examen = Ginecologia::join('examen_ginecologo', 'examen_ginecologo.idginecologia', '=', 'ginecologia.id')
            ->where('ginecologia.idpeticion', $id)
            ->get();
        //return response()->json($paciente);
        $nombrePdf = 'ginecologia_' . $paciente->paterno . " " . $paciente->materno . " " . $paciente->nombre;
        $enlace = 'https://data-net-lab.com/ginecologia/public/ginecologiaPdf/' . $id;
        // Obtener el contenido del código QR
        $qrCodePath = '../public/qrcodes/' . $id . '.jpg';
        // Verificar si el código QR ya existe
        if (!file_exists($qrCodePath)) {
            // Generar el código QR solo si no existe
            QrCode::format('png')->size(450)->generate($enlace . $id, $qrCodePath);
        }
        // Asignar el ID del código QR
        $codigoqr = $id;

        //Formateamos y agregamos dias a la FUM de la paciente
        if ($ginecologia->fum) {
            $fum = \Carbon\Carbon::parse($ginecologia->fum);
            $formatedFum = $fum->format('d/m/Y');

            // Verificamos si han pasado menos de 10 meses
            if ($fum->diffInMonths(\Carbon\Carbon::now()) < 10) {
                $daysDiff = $fum->diffInDays(\Carbon\Carbon::now());
                $formatedFum .= " y $daysDiff días";
            }
            // Asignamos el resultado al objeto
            $ginecologia->fum = $formatedFum;
        }
        // Cargar la vista y pasar los datos
        $pdf = FacadePdf::loadView('ginecologia.ginecologiaPdf', compact('medico', 'codigoqr', 'ginecologia', 'estadoPaciente', 'examen', 'paciente'))->setPaper('letter', 'portrait');
        // Descargar el PDF con un nombre específico
        $nombreArchivo = $nombrePdf . '.pdf';
        return $pdf->stream($nombreArchivo);
    }

    public function cambiarImagenMama($id)
    {

    }
}
