<?php

namespace App\Http\Controllers;

use App\Models\Institucion;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class InstitucionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('institucion.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('institucion.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //return response()->json($request);
        $rules = [
            'codigo' => 'required|string|max:255',
            'nombreInstituto' => 'required|string|max:500',
            'direccion' => 'nullable',
            'telefono' => 'nullable',
            'correo' => 'nullable',
            'nit' => 'nullable',
            'observacion' => 'nullable',
        ];
        $validatedData = $request->validate($rules);
        DB::beginTransaction();
        $institucion = new Institucion();
        $institucion->codigo = $validatedData['codigo'];
        $institucion->nombreInstituto = $validatedData['nombreInstituto'];
        $institucion->direccion = $validatedData['direccion']??'';
        $institucion->telefono = $validatedData['telefono'] ?? '';
        $institucion->correo = $validatedData['correo'] ?? '';
        $institucion->nit = $validatedData['nit'] ?? '';
        $institucion->observacion = $validatedData['observacion'] ?? '';
        $institucion->save();
        DB::commit();
        session()->flash('success', 'Institucion creado exitosamente.');
        return redirect()->route('instituciones.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $Datos = Institucion::select('institucion.*')
                    ->where('institucion.id',$id)
                    ->get();
        return response()->json($Datos);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $institucionId = $request->input('id');
        $codigo= $request->input('codigo');
        $nombreInstituto = $request->input('nombreInstituto');
        $direccion = $request->input('direccion');
        $telefono = $request->input('telefono');
        $correo = $request->input('correo');
        $nit = $request->input('nit');
        $observacion = $request->input('observacion');
         // Buscar el usuario por su ID
         $datoInstitucion = Institucion::find($institucionId);
 
         if ($datoInstitucion) {
             $datoInstitucion->codigo = $codigo;
             $datoInstitucion->nombreInstituto = $nombreInstituto;
             $datoInstitucion->direccion = $direccion;
             $datoInstitucion->telefono = $telefono;
             $datoInstitucion->correo = $correo;
             $datoInstitucion->nit = $nit;
             $datoInstitucion->observacion = $observacion;
             $datoInstitucion->save();
 
             // Opcionalmente, puedes devolver una respuesta JSON
             return response()->json(['success' => true, 'message' => 'Institucion actualizado correctamente']);
         } else {
             // Si no se encuentra el usuario, devolver un mensaje de error
             return response()->json(['success' => false, 'message' => 'Institucion no encontrado'], 404);
         }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $datos=Institucion::findOrFail($id);
        $datos->delete();
        return response()->json("elimando correctamente");
    }
    public function obtenerInstitucion(){
        $data = Institucion::all();
        return response()->json($data);
    }
}
