<?php

namespace App\Http\Controllers;

use App\Models\Medico;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class MedicoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('medico.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('medico.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //return response()->json($request);
        $rules = [
            'codigo' => 'required|string|max:255',
            'nombreMedico' => 'required|string|max:500',
            'especialidad' => 'nullable',
            'telefono' => 'nullable',
            'correo' => 'nullable',
            'colegialo' => 'nullable',
            'direccion' => 'nullable',
            'observacion' => 'nullable',
            'activo' => 'nullable',
        ];
        $validatedData = $request->validate($rules);
        DB::beginTransaction();
        $medico = new Medico();
        $medico->codigo = $validatedData['codigo'];
        $medico->nombreMedico = $validatedData['nombreMedico'];
        $medico->especialidad = $validatedData['especialidad'];
        $medico->telefono = $validatedData['telefono'] ?? '';
        $medico->correo = $validatedData['correo'] ?? '';
        $medico->colegialo = $validatedData['colegialo'] ?? '';
        $medico->direccion = $validatedData['direccion'] ?? '';
        $medico->observacion = $validatedData['observacion'] ?? '';
        $medico->activo = 0;
        $medico->save();
        DB::commit();
        session()->flash('success', 'Medico creado exitosamente.');
        return redirect()->route('medicos.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $Datos = Medico::select('medicos.*')
                    ->where('medicos.id',$id)
                    ->get();
        return response()->json($Datos);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $medicoId = $request->input('id');
        $codigo= $request->input('codigo');
        $nombreMedico = $request->input('nombreMedico');
        $especialidad = $request->input('especialidad');
        $telefono = $request->input('telefono');
        $correo = $request->input('correo');
        $colegialo = $request->input('colegialo');
        $direccion = $request->input('direccion');
        $observacion = $request->input('observacion');
        $activo = $request->input('activo'); 
         // Buscar el usuario por su ID
         $datoMedico = Medico::find($medicoId);
 
         if ($datoMedico) {
             $datoMedico->codigo = $codigo;
             $datoMedico->nombreMedico = $nombreMedico;
             $datoMedico->especialidad = $especialidad;
             $datoMedico->telefono = $telefono;
             $datoMedico->correo = $correo;
             $datoMedico->colegialo = $colegialo;
             $datoMedico->direccion = $direccion;
             $datoMedico->observacion = $observacion;
             $datoMedico->activo = $activo;
             $datoMedico->save();
 
             // Opcionalmente, puedes devolver una respuesta JSON
             return response()->json(['success' => true, 'message' => 'Medico actualizado correctamente']);
         } else {
             // Si no se encuentra el usuario, devolver un mensaje de error
             return response()->json(['success' => false, 'message' => 'Medico no encontrado'], 404);
         }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $datos=Medico::findOrFail($id);
        $datos->delete();
        return response()->json("elimando correctamente");
    }
    public function obtenerMedico(){
        $data = Medico::all();
        return response()->json($data);
    }
}
