<?php

namespace App\Http\Controllers;

use App\Models\Diagnostico;
use App\Models\Ginecologia;
use App\Models\Institucion;
use App\Models\Medico;
use App\Models\Obstetricia;
use App\Models\Paciente;
use App\Models\PacienteEstado;
use App\Models\Peticion;
use App\Models\Seguro;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Barryvdh\DomPDF\Facade\Pdf as FacadePdf;

class ObstetriciaController extends Controller
{
    //

    public function store(Request $request)
    {
        
        //dd($request);
        $idpaciente = $request->input('idpaciente');
        $registro = $request->input('registro');
        $visita = $request->input('visita');
        $tipo = $request->input('tipo');
        //$remitente = $request->input('remitente');
        //Bandera para registrar un nuevo dx
        $editarDx = $request->input('editar-dx');
        //transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);

        $diagnosticoId = $request->input('diagnostico_id');
        // Iniciar la transacción
        DB::beginTransaction();

        try {
            //editamos diagnostico y seguro
            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();

            //Creamos un nuevo diagnosito de tipo 5 si editarDx es true
            if ($editarDx) {
                if($diagnosticoId){
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 5;
                    $diagnostico->save(); 
                }else{
                    //si no se manda diagnotico_id es por que no existe un diagnostico previo
                    $diagnostico = new Diagnostico();
                    $diagnostico->idpaciente = $idpaciente;
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->tipo = 100;
                    $diagnostico->save();
                }
            }

            // Crear y guardar la Peticion
            $peticion = new Peticion();
            $peticion->registro = $registro;
            $peticion->visita = $visita;
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->idpaciente = $idpaciente;
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            //$peticion->remitente = $remitente;
            $peticion->tipo = $tipo;
            $peticion->save();

            $estadoPaciente = new PacienteEstado();
            $estadoPaciente->idpeticion = $peticion->id;
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            $ginecologia = new Ginecologia();
            $ginecologia->idpeticion = $peticion->id;
            $ginecologia->motivo = $request->input('motivo');
            $ginecologia->enfermedad = $request->input('enfermedad');
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->conclusion = $request->input('conclusion');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->save();
            if ($tipo == 5) {
                $obstetricia = new Obstetricia();
                $obstetricia->idginecologia = $ginecologia->id;
                $obstetricia->semanas = $request->input('semanas');
                $obstetricia->dias = $request->input('dias');
                $obstetricia->uterino = $request->input('uterino');
                $obstetricia->movilidad = $request->input('movilidad');
                $obstetricia->peso_fetal = $request->input('peso_fetal');
                $obstetricia->posicion = $request->input('posicion');
                $obstetricia->placenta = $request->input('placenta');
                $obstetricia->liq_amn = $request->input('liq_amn');
                $obstetricia->fcf = $request->input('fcf');
                $obstetricia->presentacion = $request->input('presentacion');
                $obstetricia->fecha_parto = $request->input('fecha_parto');
                $obstetricia->posicion_placenta = $request->input('posicion_placenta');
                $obstetricia->posicion_presentacion = $request->input('posicion_presentacion');
                $obstetricia->producto = $request->input('producto');
                $obstetricia->save();
            }
            // Confirmar la transacción
            DB::commit();
            session()->flash('success', 'Destino de Informe creado exitosamente.');
            return redirect()->route('obstetricia.show', $peticion->id);
        } catch (\Exception $e) {
            dd('error: ', $e);
            // En caso de error, hacer rollback de la transacción
            DB::rollBack();
            session()->flash('error', 'Ocurrió un error al crear o actualizar el Destino de Informe: ' . $e->getMessage());
            return redirect()->back()->withInput();
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $datos = DB::table('peticiones')
            ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
            ->where('peticiones.id', $id)
            ->select('peticiones.*', 'pacientes.*')
            ->get();

        $paciente = Paciente::find($datos[0]->idpaciente);
        $seguros = Seguro::all();
        $estadoPaciente = PacienteEstado::where('idpeticion', $id)->get();
        $datosGinecologia = Ginecologia::where('idpeticion', $id)->get();
        $obstetricia = Ginecologia::join('obstetricia', 'obstetricia.idginecologia', '=', 'ginecologia.id')
            ->where('ginecologia.idpeticion', $id)
            ->get();
        //return response()->json($examen);
        $medico = Medico::all();
        //filtramos sus diagnosticos
        $diagnosticoGineco = $paciente->diagnosticos->where('tipo', 5)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if($diagnosticoGineco){
            $datos[0]->diagnostico_id = $diagnosticoGineco->id;
            $datos[0]->diagnostico = $diagnosticoGineco->nombre;
        }else if($diagnosticoOrigen){

            $datos[0]->diagnostico_id = $diagnosticoOrigen->id;
            $datos[0]->diagnostico = $diagnosticoOrigen->nombre;
        } else{
            $datos[0]->diagnostico_id = null;
            $datos[0]->diagnostico = null;
        }
        return view('obstetricia.show', compact('datos', 'id', 'medico', 'estadoPaciente', 'datosGinecologia', 'obstetricia', 'paciente', 'seguros'));
    }
    public function crearObstetricia($id)
    {
        $medico = DB::table('medicos')->select('medicos.*')->get();
        $paciente = Paciente::find($id);
        $seguros = Seguro::all();
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')->where('pacientes.id', '=', $id)->get();

        $historicoEstado = Peticion::join('paciente_estado', 'paciente_estado.idpeticion', '=', 'peticiones.id')
            ->select('peticiones.visita', 'paciente_estado.*')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 5)
            ->get();

            $diagnosticoGineco = $paciente->diagnosticos->where('tipo', 5)->sortByDesc('created_at')->first();
            $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
            //se prioriza el de gineco
            if($diagnosticoGineco){
                $datos[0]->diagnostico_id = $diagnosticoGineco->id;
                $datos[0]->diagnostico = $diagnosticoGineco->nombre;
            }else if($diagnosticoOrigen){
    
                $datos[0]->diagnostico_id = $diagnosticoOrigen->id;
                $datos[0]->diagnostico = $diagnosticoOrigen->nombre;
            } else{
                $datos[0]->diagnostico_id = null;
                $datos[0]->diagnostico = null;
            }
        return view('obstetricia.create', compact('datos', 'id', 'hoy', 'medico', 'historicoEstado', 'paciente', 'seguros'));
    }

    public function editarObstetricia(Request $request, $id)
    {
        $idpaciente = $request->input('idpaciente');
        $registro = $request->input('registro');
        $visita = $request->input('visita');
        $tipo = $request->input('tipo');

        $editarDx = $request->input('editarDx');
        $diagnostico_id = $request->input('diagnosticoId');
        //transformar a boolean el valor editarDx
        $editarDx = filter_var($editarDx, FILTER_VALIDATE_BOOLEAN);
        //$proveniencia = $request->input('proveniencia');
        $remitente = $request->input('remitente');
        // Iniciar la transacción
        DB::beginTransaction();

        try {

            $paciente = Paciente::where('id', $idpaciente)->firstOrFail();
            $paciente->idseguro = $request->input('idseguro');
            $paciente->save();
            // Actualizar el registro existente
            $peticion = Peticion::where('id', $id)->firstOrFail();
            $peticion->registro = $registro;
            $peticion->visita = $visita;
            $peticion->idmedico = 1; // Suponemos que el idmedico es fijo o se obtiene de otro lugar
            $peticion->idpaciente = $idpaciente;
            $peticion->estado = 0;
            $peticion->proveniencia = $paciente->institucion->nombreInstituto;
            $peticion->remitente = $remitente;
            $peticion->tipo = $tipo;
            $peticion->save();

            //Editar el diagnostico del informe
            if ($editarDx) {
                //buscamos el diagnostico y le cambiamos el nombre
                if($diagnostico_id){
                    $diagnostico = Diagnostico::where('id', $diagnostico_id)->firstOrFail();
                    $diagnostico->nombre = $request->input('diagnostico');
                    $diagnostico->save();
                }else{
                    Diagnostico::create([
                        'idpaciente' => $idpaciente,
                        'nombre' => $request->input('diagnostico'),
                        'tipo' => 100,
                    ]);
                }
            }
            $estadoPaciente = PacienteEstado::where('idpeticion', $id)->firstOrFail();
            $estadoPaciente->idpeticion = $peticion->id;
            $estadoPaciente->peso = $request->input('peso');
            $estadoPaciente->talla = $request->input('talla');
            $estadoPaciente->imc = $request->input('imc');
            $estadoPaciente->pa = $request->input('pa');
            $estadoPaciente->pa1 = $request->input('pa1');
            $estadoPaciente->fc = $request->input('fc');
            $estadoPaciente->fr = $request->input('fr');
            $estadoPaciente->sat = $request->input('sat');
            $estadoPaciente->temp = $request->input('temp');
            $estadoPaciente->ps = $request->input('ps');
            $estadoPaciente->sc = $request->input('sc');
            $estadoPaciente->save();

            $ginecologia = Ginecologia::where('idpeticion', $id)->firstOrFail();
            $ginecologia->idpeticion = $peticion->id;
            $ginecologia->motivo = $request->input('motivo');
            $ginecologia->enfermedad = $request->input('enfermedad');
            $ginecologia->antecedentes = $request->input('antecedentes');
            $ginecologia->antecedentes_familiares = $request->input('antecedentes_familiares');
            $ginecologia->menarca = $request->input('menarca');
            $ginecologia->ritmo = $request->input('ritmo');
            $ginecologia->mac = $request->input('mac');
            $ginecologia->pap = $request->input('pap');
            $ginecologia->fum = $request->input('fum');
            $ginecologia->gestas = $request->input('gestas');
            $ginecologia->partos = $request->input('partos');
            $ginecologia->abortos = $request->input('abortos');
            $ginecologia->cesareas = $request->input('cesareas');
            $ginecologia->irs = $request->input('irs');
            $ginecologia->fup = $request->input('fup');
            $ginecologia->fuab = $request->input('fuab');
            $ginecologia->fuc = $request->input('fuc');
            $ginecologia->resultado_pap = $request->input('resultado_pap');
            $ginecologia->psex = $request->input('psex');
            $ginecologia->ecografia = $request->input('ecografia');
            $ginecologia->conclusion = $request->input('conclusion');
            $ginecologia->tratamiento = $request->input('tratamiento');
            $ginecologia->control = $request->input('control');
            $ginecologia->save();
            if ($tipo == 5) {
                $obstetricia = Obstetricia::where('idginecologia', $ginecologia->id)->first();
                $obstetricia->idginecologia = $ginecologia->id;
                $obstetricia->semanas = $request->input('semanas');
                $obstetricia->dias = $request->input('dias');
                $obstetricia->uterino = $request->input('uterino');
                $obstetricia->movilidad = $request->input('movilidad');
                $obstetricia->peso_fetal = $request->input('peso_fetal');
                $obstetricia->posicion = $request->input('posicion');
                $obstetricia->placenta = $request->input('placenta');
                $obstetricia->liq_amn = $request->input('liq_amn');
                $obstetricia->fcf = $request->input('fcf');
                $obstetricia->presentacion = $request->input('presentacion');
                $obstetricia->fecha_parto = $request->input('fecha_parto');
                $obstetricia->posicion_placenta = $request->input('posicion_placenta');
                $obstetricia->posicion_presentacion = $request->input('posicion_presentacion');
                $obstetricia->producto = $request->input('producto');
                $obstetricia->save();
            }
            // Confirmar la transacción
            DB::commit();
            session()->flash('success', 'Registro actualizado exitosamente.');
            return response()->json(['success' => 'Registro actualizado exitosamente.']);
            //return redirect()->route('obstetricia.show', $obstetricia->id);
        } catch (\Exception $e) {
            // En caso de error, hacer rollback de la transacción
            DB::rollBack();
            session()->flash('error', 'Ocurrió un error al actualizar el registro: ' . $e->getMessage());
            return redirect()->back()->withInput();
        }

    }

    public function obstetriciaPdf($id)
    {
        $peticion = Peticion::with('ginecologia', 'paciente', 'pacienteEstado')->find($id);
        $ginecologia = $peticion->ginecologia;
        $obstetricia = $ginecologia->obstetricia;
        $examen = $ginecologia->examen;
        $perfilHormonal = $ginecologia->perfilHormonal;
        $paciente = $peticion->paciente;
        $pareja = $paciente->pareja;
        $estadoPaciente = $peticion->pacienteEstado;
        $medico = Medico::first();
        //filtramos sus diagnosticos
        $diagnosticoFertilidad = $paciente->diagnosticos->where('tipo', 5)->sortByDesc('created_at')->first();
        $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
        //se prioriza el de gineco
        if ($diagnosticoFertilidad) {
            $paciente->diagnostico_id = $diagnosticoFertilidad->id;
            $paciente->diagnostico = $diagnosticoFertilidad->nombre;
        } else if ($diagnosticoOrigen) {

            $paciente->diagnostico_id = $diagnosticoOrigen->id;
            $paciente->diagnostico = $diagnosticoOrigen->nombre;
        } else {
            $paciente->diagnostico_id = null;
            $paciente->diagnostico = null;
        }
        //--------------------------------------GENERAR QR--------------------
        $nombrePdf = 'Obstetricia_' . $paciente->paterno . " " . $paciente->materno . " " . $paciente->nombre;
        $enlace = 'https://data-net-lab.com/ginecologia/public/obstetriciaPdf/' . $id;

        $qrCodePath = '../public/qrcodes/' . $id . '.png';
        // Verificar si el código QR ya existe
        if (!file_exists($qrCodePath)) {
            // Generar el código QR solo si no existe
            QrCode::format('png')->size(450)->generate($enlace . $id, $qrCodePath);
        }
        // Asignar el ID del código QR
        $codigoqr = $id;

        //Formateamos y agregamos dias a la FUM de la paciente
        if ($ginecologia->fum) {
            $fum = \Carbon\Carbon::parse($ginecologia->fum);
            $formatedFum = $fum->format('d/m/Y');
        
            // Verificamos si han pasado menos de 10 meses
            if ($fum->diffInMonths(\Carbon\Carbon::now()) < 10) {
                $daysDiff = $fum->diffInDays(\Carbon\Carbon::now());
                $formatedFum .= " y $daysDiff días";
            }
            // Asignamos el resultado al objeto
            $ginecologia->fum = $formatedFum;
        }
        $paciente->edad_actual = date_diff(date_create($paciente->nacimiento), date_create('now'))->y;
        // Cargar la vista y pasar los datos
        $pdf = FacadePdf::loadView('obstetricia.obstetriciaPdf', compact('medico', 'paciente', 'codigoqr', 'ginecologia', 'estadoPaciente','obstetricia'))->setPaper('letter', 'portrait');
        // Descargar el PDF con un nombre específico
        $nombreArchivo = $nombrePdf . '.pdf';
        return $pdf->stream($nombreArchivo);
    }

    public function historialInformacionObstetricia($id)
    {
        $datohoy = date("ymd" . '%');
        $consultacont = "SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '" . $datohoy . "'";
        $consultacontdb = DB::select($consultacont);
        $hoy = date("ymd" . str_pad($consultacontdb[0]->cantidad + 1, 3, "0", STR_PAD_LEFT));
        $datos = DB::table('pacientes')->where('pacientes.id', '=', $id)->get();
        return view('obstetricia.resultadosHistorial', compact('datos', 'id', 'hoy'));
    }

    public function obtenerHistorialObstetricia($id)
    {
        $data = DB::table('peticiones')
            ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
            ->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')
            ->where('peticiones.idpaciente', $id)
            ->where('peticiones.tipo', 5)
            ->select('peticiones.*', 'institucion.nombreInstituto')
            ->orderBy('peticiones.visita', 'DESC')
            ->get();
        return response()->json($data);
    }
}
