<?php

namespace App\Http\Controllers;

use App\Models\Diagnostico;
use App\Models\Institucion;
use App\Models\Paciente;
use App\Models\Seguro;
use App\Models\Sexo;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PacienteController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('paciente.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $idHistorial = Paciente::orderBy('id', 'desc')->select('historial')->first();
        $sexos = Sexo::all();
        $institucion = Institucion::all();
        $seguros = Seguro::all();
        //return response()->json($idHistorial);
        session(['previous_url' => url()->previous()]);
        return view('paciente.create', compact('idHistorial', 'institucion', 'seguros'));
    }



    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //return response()->json($request);
        $previo = session('previous_url');
        $rules = [
            'historial' => 'required|string|max:255',
            'paterno' => 'nullable|string|max:255',
            'materno' => 'nullable|string|max:255',
            'nombre' => 'nullable|string|max:255',
            'nacimiento' => 'nullable|date',
            'edad' => 'nullable|integer|min:0',
            'sexo' => 'nullable|string|max:255',
            'direccion' => 'nullable|string|max:255',
            'profesion' => 'nullable|string|max:255',
            'residencia' => 'nullable|string|max:255',
            'civil' => 'nullable|string|max:255',
            'ci' => 'nullable|string|max:20',
            'telefono' => 'nullable|string|max:20',
            'alergia' => 'nullable|string|max:3000',
            'comorbilidad' => 'nullable|string|max:255',
            'procedencia' => 'nullable|string|max:255',
            'familiar1' => 'nullable|string|max:255',
            'telefono1' => 'nullable|string|max:20',
            'familiar2' => 'nullable|string|max:255',
            'telefono2' => 'nullable|string|max:20',
            'sanguineo' => 'nullable|string|max:3',
            'diagnostico' => 'nullable|string|max:255',
            'deceso' => 'nullable|string|max:255',
            'fecha_diagnostico' => 'nullable|date',
            'fecha_deceso' => 'nullable|date',
            'idinstitucion' => 'nullable|integer|min:0',
            'asegurado1' => 'nullable|string|max:255',
            'seguro' => 'nullable|integer|min:0',
        ];

        $rulesPareja = [
            'paterno_pareja' => 'nullable|string|max:255',
            'materno_pareja' => 'nullable|string|max:255',
            'nombre_pareja' => 'nullable|string|max:255',
            'ci_pareja' => 'nullable|string|max:50',
            'telefono_pareja' => 'nullable|string|max:50',
            'edad_pareja' => 'nullable|integer|min:0',
            'profesion_pareja' => 'nullable|string|max:255',
            'nacimiento_pareja' => 'nullable|date',
            'direccion_pareja' => 'nullable|string|max:255',
        ];

        $validatedData = $request->validate($rules);
        $datosPareja = $request->validate($rulesPareja);

        $LetraPat = strtoupper(substr($validatedData['paterno'] ?? '', 0, 1));
        $LetraMat = strtoupper(substr($validatedData['materno'] ?? '', 0, 1));
        $LetraNom = strtoupper(substr($validatedData['nombre'] ?? '', 0, 1));
        $cantidad_registros = Paciente::count() + 1;
        $valor = str_pad($cantidad_registros, 6, "0", STR_PAD_LEFT);
        $codPaciente = $LetraPat . $LetraMat . $LetraNom . "-" . $valor;

        DB::beginTransaction();
        try {
            $paciente = new Paciente();
            $paciente->fill([
                'historial' => $validatedData['historial'],
                'codigoPaciente' => $codPaciente,
                'paterno' => $validatedData['paterno'] ?? null,
                'materno' => $validatedData['materno'] ?? null,
                'nombre' => $validatedData['nombre'] ?? null,
                'nacimiento' => $validatedData['nacimiento'] ?? null,
                'sexo' => $validatedData['sexo'] ?? '',
                'direccion' => $validatedData['direccion'] ?? null,
                'profesion' => $validatedData['profesion'] ?? null,
                'residencia' => $validatedData['residencia'] ?? null,
                'civil' => $validatedData['civil'] ?? null,
                'ci' => $validatedData['ci'] ?? '',
                'telefono' => $validatedData['telefono'] ?? '',
                'alergia' => $validatedData['alergia'] ?? null,
                'comorbilidad' => $validatedData['comorbilidad'] ?? null,
                'procedencia' => $validatedData['procedencia'] ?? null,
                'familiar1' => $validatedData['familiar1'] ?? null,
                'telefono1' => $validatedData['telefono1'] ?? null,
                'familiar2' => $validatedData['familiar2'] ?? null,
                'telefono2' => $validatedData['telefono2'] ?? null,
                'sanguineo' => $validatedData['sanguineo'] ?? null,
                'deceso' => $validatedData['deceso'] ?? null,
                'fecha_diagnostico' => $validatedData['fecha_diagnostico'] ?? null,
                'fecha_deceso' => $validatedData['fecha_deceso'] ?? null,
                'edad' => $validatedData['edad'] ?? null,
                'asegurado1' => $validatedData['asegurado1'] ?? null,
                'idinstitucion' => $validatedData['idinstitucion'] ?? null,
                'idseguro' => $validatedData['seguro']
            ]);
            $paciente->save();

            //crear pareja
            $paciente->pareja()->create($datosPareja);

            //Si se manda un diagnostico lo guardamos en diagnosticos con con un tipo 100
            if (!empty($validatedData['diagnostico'])) {
                Diagnostico::create([
                    'idpaciente' => $paciente->id,
                    'nombre' => $validatedData['diagnostico'],
                    'tipo' => 100
                ]);
            }

            DB::commit();

            session()->flash('success', 'Paciente creado exitosamente.');
            return redirect($previo)->with('ultimoPaciente', $paciente);
        } catch (\Exception $e) {
            DB::rollBack();
            // Log the error for debugging

            return redirect()->back()->withErrors(['error' => 'Ocurrió un error al crear el paciente.: ' . $e->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $Datos = Paciente::select('pacientes.*')
            ->where('pacientes.id', $id)
            ->get();
        $institucion = Institucion::all();
        $seguros = Seguro::all();
        $paciente = Paciente::find($id);
        $paciente->diagnostico = $paciente->diagnosticos->where('tipo', 100)->first()->nombre ?? '';
        session(['previous_url' => url()->previous()]);
        return view('paciente.edit', compact('institucion', 'Datos', 'seguros', 'paciente'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $previo = session('previous_url');
        //return response()->json($request);
        $paterno = $request->input('paterno');
        $materno = $request->input('materno');
        $nombre = $request->input('nombre');
        $nacimiento = $request->input('nacimiento');
        $sexo = $request->input('sexo');
        $ci = $request->input('ci');
        $edad = $request->input('edad');
        $institucion = $request->input('institucion');
        $diagnostico = $request->input('diagnostico');
        $seguro = $request->input('seguro');
        DB::beginTransaction();
        try {
            // Buscar el usuario por su ID
            $datoPaciente = Paciente::findOrFail($id);
            $datoPaciente->paterno = $paterno;
            $datoPaciente->materno = $materno;
            $datoPaciente->nombre = $nombre;
            $datoPaciente->nacimiento = $nacimiento;
            $datoPaciente->sexo = $sexo;
            $datoPaciente->ci = $ci;
            $datoPaciente->edad = $edad;
            $datoPaciente->idinstitucion = $institucion;
            $datoPaciente->idseguro = $seguro;
            //profesion y telefono
            $datoPaciente->profesion = $request->input('profesion');
            $datoPaciente->telefono = $request->input('telefono');
            $datoPaciente->direccion = $request->input('direccion');
            $datoPaciente->save();

            //Editamos los datos de la pareja

            $pareja = $datoPaciente->pareja;
            if ($pareja) {
                $pareja->paterno_pareja = $request->input('paterno_pareja');
                $pareja->materno_pareja = $request->input('materno_pareja');
                $pareja->nombre_pareja = $request->input('nombre_pareja');
                $pareja->ci_pareja = $request->input('ci_pareja');
                $pareja->telefono_pareja = $request->input('telefono_pareja');
                $pareja->edad_pareja = $request->input('edad_pareja');
                $pareja->profesion_pareja = $request->input('profesion_pareja');
                $pareja->nacimiento_pareja = $request->input('nacimiento_pareja');
                $pareja->direccion_pareja = $request->input('direccion_pareja');
                $pareja->save();
            } else {
                $pareja = $datoPaciente->pareja()->create($request->only([
                    'paterno_pareja',
                    'materno_pareja',
                    'nombre_pareja',
                    'ci_pareja',
                    'telefono_pareja',
                    'edad_pareja',
                    'profesion_pareja',
                    'nacimiento_pareja',
                    'direccion_pareja',
                ]));
            }

            // Verificar si el diagnóstico fue enviado
            if (!empty($diagnostico)) {
                // Buscar el diagnóstico existente de tipo 100 para este paciente
                $diagnosticoExistente = Diagnostico::where('idpaciente', $datoPaciente->id)
                    ->where('tipo', 100)
                    ->first();

                if ($diagnosticoExistente) {
                    // Si existe, actualizarlo
                    $diagnosticoExistente->nombre = $request->input('diagnostico');
                    $diagnosticoExistente->save();
                } else {
                    // Si no existe, crear un nuevo diagnóstico
                    Diagnostico::create([
                        'nombre' => $request->input('diagnostico'),
                        'idpaciente' => $datoPaciente->id, // Relación con el paciente
                        'tipo' => 100 // Tipo reservado para Diagnóstico de origen
                    ]);
                }
            }
            session()->flash('success', 'Datos del Paciente Actualizado exitosamente.');
            DB::commit();


            return redirect($previo)->with('ultimoPaciente', $datoPaciente);
        } catch (\Exception $e) {
            DB::rollBack();
            // Log the error for debugging

            return redirect()->back()->withErrors(['error' => 'Ocurrió un error al crear el paciente.: ' . $e->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $datos = Paciente::findOrFail($id);
        $datos->delete();
        return response()->json("elimando correctamente");
    }
    public function obtenerPaciente()
    {
        $data = Paciente::select('pacientes.*')
            ->orderBy('pacientes.id', 'DESC')
            ->get();
        return response()->json($data);
    }

    public function crearGinecologia()
    {
        $idHistorial = Paciente::orderBy('id', 'desc')->select('historial')->first();
        $sexos = Sexo::all();
        $institucion = Institucion::all();
        //return response()->json($idHistorial);
        return view('paciente.crearPacienteGine', compact('idHistorial', 'institucion'));
    }


    public function obtenerHistorialDx($id)
    {
        // Suponiendo que tienes un modelo Diagnostico y un método para obtener los diagnósticos
        $diagnosticos = Diagnostico::where('idpaciente', $id)->get();

        // Inicializar los arrays para los diferentes tipos de diagnósticos
        //el origen debe contener un unico dx es el tipo 100 el primero que se encuentra first
        $origen = $diagnosticos->where('tipo', 100)->first();
        $ginecologia = [];
        $obstetricia = [];

        // Clasificar los diagnósticos en sus respectivos arrays
        foreach ($diagnosticos as $diagnostico) {
            switch ($diagnostico->tipo) {
                case 4:
                    // Tipo 4 corresponde a ginecología
                    $ginecologia[] = $diagnostico;
                    break;
                case 5:
                    // Tipo 5 corresponde a obstetricia
                    $obstetricia[] = $diagnostico;
                    break;
            }
        }

        // Construir el array que se devolverá como JSON
        $resultado = [
            'origen' => $origen,
            'ginecologia' => $ginecologia,
            'obstetricia' => $obstetricia,
        ];

        // Devolver la respuesta JSON
        return response()->json($resultado);
    }

}
