<?php

namespace App\Http\Controllers;

use App\Models\Imagen;
use App\Models\Informe;
use App\Models\Institucion;
use App\Models\Medico;
use App\Models\Paciente;
use App\Models\Peticion;
use App\Models\TipoPeticion;
use Barryvdh\DomPDF\Facade\Pdf as FacadePdf;
use Barryvdh\DomPDF\PDF;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use App\Exports\Pacientes;
use Maatwebsite\Excel\Facades\Excel;

class PeticionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('peticion.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $instituciones=Institucion::all();
        $medicos=Medico::all();
        $tipoPeticion=TipoPeticion::all();
        $datohoy=date("ymd".'%');
        $consultacont="SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '".$datohoy."'";
        $consultacontdb=DB::select($consultacont);
        $hoy=date("ymd".str_pad($consultacontdb[0]->cantidad+1, 3, "0", STR_PAD_LEFT));
        $ultimoRegistro=Peticion::latest('id')->value('peticiones.registro');
        return view('peticion.create',compact('instituciones','medicos','tipoPeticion','hoy','ultimoRegistro'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
       
    }

    public function guardarInformacion(Request $request)
    {
        //return response()->json($request);
        $rules = [
            'registro' => 'nullable',
            'visita' => 'nullable',
            'idpaciente' => 'required',
            'interpretacion' => 'nullable',
            'comentario' => 'nullable',
            'macroscopico' => 'nullable',
            'microscopico' => 'nullable',
            'estado'=>'nullable',
            'tipo'=>'nullable',
            'proveniencia'=>'nullable',
            'remitente'=>'nullable',
        ];
        $validatedData = $request->validate($rules);

        DB::beginTransaction();
        try {
            $peticion = new Peticion();
            $peticion->registro = $validatedData['registro'];
            $peticion->visita = $validatedData['visita'];
            $peticion->idmedico = 1;  // This should be dynamic if possible
            $peticion->idpaciente = $validatedData['idpaciente'];
            $peticion->proveniencia=$validatedData['proveniencia'];
            $peticion->remitente=$validatedData['remitente'];
            $peticion->tipo=$validatedData['tipo'];
            $peticion->estado=$validatedData['estado'];
            $peticion->save();

            $informes = [
                'interpretacion' => 'INTERPRETACIÓN',
                'comentario' => 'COMENTARIO',
                'macroscopico' => 'MACROSCOPICO',
                'microscopico' => 'MICROSCOPICO'
            ];

            foreach ($informes as $key => $titulo) {
                if (isset($validatedData[$key])) {
                    $informe = new Informe();
                    $informe->idpeticion = $peticion->id;
                    $informe->titulo = $titulo;
                    $informe->descripcion = $validatedData[$key] ?? null;
                    $informe->save();
                }
            }
            DB::commit();
           $figuras=$request->input('figura');
           $cont=0;
            if ($request->hasFile('ruta')) {
                $imagenes = $request->file('ruta');
                foreach ($imagenes as $imagen) {
                    $nombreImagen = time() . '_' . $imagen->getClientOriginalName();
                    $rutaImagen = $imagen->move(public_path('images'), $nombreImagen);
                Imagen::create([
                    'idpeticion' => $peticion->id,
                    'ruta' => 'images/' . $nombreImagen,
                    'figura'=>$figuras[$cont],
                ]);
                $cont=$cont+1;
                }
            }

        session()->flash('success', 'Destino de Informe creado exitosamente.');
        return redirect()->route('resultado', $peticion->id);
    } catch (\Exception $e) {
        DB::rollBack();
        session()->flash('error', 'Ocurrió un error al crear o actualizar el Destino de Informe: ' . $e->getMessage());
        return redirect()->back()->withInput();
    }
}

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
    public function filtrarPacientePorParametro(Request $request)
    {

        $query = Paciente::query();
    
        // Filtrar por cada campo si existe en la solicitud
        if ($request->filled('id')) {
            $query->where('id', $request->input('id'));
        }
        if ($request->filled('ci')) {
            $query->where('ci', $request->input('ci'));
        }
        if ($request->filled('paterno')) {
            $query->where(function($q) use ($request) {
                $q->where('paterno', 'like', $request->input('paterno') . '%') // Prioriza los que empiezan
                  ->orWhere('paterno', 'like', '%' . $request->input('paterno') . '%'); // Luego busca los que contienen
            })->orderByRaw("paterno LIKE '" . $request->input('paterno') . "%' DESC"); // Ordena para priorizar los que empiezan
        }
        
        if ($request->filled('materno')) {
            $query->where(function($q) use ($request) {
                $q->where('materno', 'like', $request->input('materno') . '%')
                  ->orWhere('materno', 'like', '%' . $request->input('materno') . '%');
            })->orderByRaw("materno LIKE '" . $request->input('materno') . "%' DESC");
        }
        
        if ($request->filled('nombre')) {
            $query->where(function($q) use ($request) {
                $q->where('nombre', 'like', $request->input('nombre') . '%')
                  ->orWhere('nombre', 'like', '%' . $request->input('nombre') . '%');
            })->orderByRaw("nombre LIKE '" . $request->input('nombre') . "%' DESC");
        }
        if ($request->filled('sexo')) {
            $query->where('sexo', $request->input('sexo'));
        }
        if ($request->filled('edad')) {
            $query->where('edad', $request->input('edad'));
        }
        if ($request->filled('nacimiento')) {
            $query->where('nacimiento', $request->input('nacimiento'));
        }
        $query->orderBy('id', 'desc');
        $pacientes = $query->get();
    
        // Asignamos el atributo temporal 'seguro' a cada paciente
        foreach ($pacientes as $paciente) {
                 $diagnosticoOrigen = $paciente->diagnosticos->where('tipo', 100)->sortByDesc('created_at')->first();
                 // Se prioriza el diagnóstico de gineco (tipo 4)
                if ($diagnosticoOrigen) {
                     $paciente->diagnostico = $diagnosticoOrigen->nombre;
                 } else {
                     $paciente->diagnostico = null;
                 }
        }
        // Devolvemos los pacientes con el atributo 'seguro' agregado solo en el resultado
        return response()->json($pacientes);
    }
    
    public function obtenerTecnica(string $id){
        $obtenerTecnica=DB::select("SELECT *
                        FROM parametros
                        WHERE parametros.id=".$id);
        return response()->json($obtenerTecnica);
    }

    public function filtrarPaciente(string $id){
        $datos = Paciente::where('paterno', 'like', $id.'%')
            ->orderBy('paterno', 'asc')->get();

        return response()->json($datos);
    }

    public function filtrarPacienteCodigo(string $id){

        //return response()->json($id);
        $datos = Paciente::where('historial', $id)
                    ->orWhere('asegurado1', $id)
                    ->get();

        return response()->json($datos);
    }

    public function filtrarPacienteCi(string $id){

        //return response()->json($id);
        $datos = Paciente::where('ci', $id)
                    ->get();
        return response()->json($datos);
    }

    public function filtrarPacienteDiagnostico(string $id){

        //return response()->json($id);
        $datos = Paciente::where('diagnostico','like',$id.'%')
                    ->get();
        return response()->json($datos);
    }

    public function filtrarPacienteSexo(string $id){

        //return response()->json($id);
        $datos = Paciente::where('sexo','like',$id)
                    ->get();
        return response()->json($datos);
    }

    public function filtrarPacienteEdad(string $id){

        //return response()->json($id);
        $datos = Paciente::where('edad',$id)
                    ->get();
        return response()->json($datos);
    }
    public function filtrarPacienteNombre(Request $request){
        $paterno = $request->input('paterno');
        $materno = $request->input('materno');
        $nombre = $request->input('nombre');
        //return response()->json($request);
        $datos = Paciente::where('paterno','like',$paterno.'%')
                    ->where('materno', 'like',$materno.'%')
                    ->where('nombre', 'like',$nombre.'%')
                    ->get();
        return response()->json($datos);
    }

    public function filtrarPacienteMaterno(Request $request){
        $paterno = $request->input('paterno');
        $materno = $request->input('materno');
        //return response()->json($request);
        $datos = Paciente::where('paterno','like',$paterno.'%')
                    ->where('materno', 'like',$materno.'%')
                    ->get();
        return response()->json($datos);
    }

    public function busquedaPaciente(Request $request){
        $historial = $request->input('obtHis');
        $carnet = $request->input('obtCi');
        $apellidos = $request->input('obtAp');
        $nombres = $request->input('obtNom');
        
        if ($historial == null && $carnet == null && $apellidos == null && $nombres == null) {
            return response()->json(['alerta' => 'No se proporcionó ningún dato de búsqueda.'], 400);
        }
    
        $query = Paciente::query();
        if ($historial != null) {
            $query->where('historial', '=', $historial);
        }
    
        if ($carnet != null) {
            $query->where('ci', 'LIKE', '%'.$carnet.'%');
        }
    
        if ($apellidos != null) {
            $query->where('apellidos', 'LIKE', '%'.$apellidos.'%');
        }
    
        if ($nombres != null) {
            $query->where('nombres', 'LIKE', '%'.$nombres.'%');
        }

        $datosPacientes = $query->get();
        return response()->json($datosPacientes);
    }

    public function obtenerPeticiones(){
        $datos=DB::table('peticiones')
        ->join('pacientes','pacientes.id','=','peticiones.idpaciente')
        ->select('peticiones.id','peticiones.registro','peticiones.idpaciente','pacientes.historial','pacientes.apellidos',
        'pacientes.nombres','pacientes.nacimiento','pacientes.edad','pacientes.observacion','pacientes.ci','peticiones.visita')->get();
        return response()->json($datos);
    }

    public function resultado($id){
        $datos = DB::table('peticiones')
        ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
        ->where('peticiones.id', $id)
        ->select('peticiones.*', 'pacientes.*')
        ->get();
        $informes = Informe::where('idpeticion', $id)->get();
        $imagenes = Imagen::where('idpeticion',$id)->get();
        $medico=Medico::all();
        //return response()->json($datos);
         return view('peticion.resultados',compact('datos','informes','imagenes','id','medico'));
    }

    public function resultadoInformacion($id){
        $resultadoPaciente = DB::table('peticiones')
        ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
        ->where('peticiones.id', $id)
        ->select('peticiones.*', 'pacientes.*')
        ->get();
        $informes = Informe::where('idpeticion', $id)->get();
        $imagenes = Imagen::where('idpeticion',$id)->get();
        //return response()->json($resultadoPaciente);
         return view('peticion.resultadosInfo',compact('resultadoPaciente','informes','imagenes','id'));
    }

    public function historialInformacion($id){
        
        $datohoy=date("ymd".'%');
        $consultacont="SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '".$datohoy."'";
        $consultacontdb=DB::select($consultacont);
        $hoy=date("ymd".str_pad($consultacontdb[0]->cantidad+1, 3, "0", STR_PAD_LEFT));
        $datos=DB::table('pacientes')->where('pacientes.id','=',$id)->get();
        return view('peticion.resultadosHistorial',compact('datos','id','hoy'));
    }

    public function informaciones(){
        return view('peticion.informacion');
    }

    public function informacionGinecologia(){
        return view('peticion.infoGinecologia');
    }

    public function crearInformacion($id){
        $medico=DB::table('medicos')->select('medicos.*')->get();
        $datohoy=date("ymd".'%');
        $consultacont="SELECT COUNT(peticiones.registro) AS cantidad
        FROM peticiones
        WHERE peticiones.registro LIKE '".$datohoy."'";
        $consultacontdb=DB::select($consultacont);
        $hoy=date("ymd".str_pad($consultacontdb[0]->cantidad+1, 3, "0", STR_PAD_LEFT));
        $datos=DB::table('pacientes')->join('institucion','institucion.id','=','pacientes.idinstitucion')->where('pacientes.id','=',$id)->get();
        //return response()->json($datos);
        return view('peticion.crearInformacion',compact('datos','id','hoy','medico'));
    }

    public function obtenerHistorial($id){
        $data = DB::table('peticiones')
        ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
        ->join('institucion', 'institucion.id', '=', 'pacientes.idinstitucion')
        ->where('peticiones.idpaciente', $id)
        ->where('peticiones.tipo', 1)
        ->select('peticiones.*', 'institucion.nombreInstituto')
        ->orderBy('peticiones.visita','DESC')
        ->get();
        return response()->json($data);
    }



    public function patologiaPdf($id){

        $datosMedico=DB::table('medicos')->select('medicos.*')->get();
        $datosPaciente = Peticion::where('peticiones.id', $id)
        ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
        ->select('peticiones.*', 'pacientes.*')
        ->first();
        //return response()->json($datosPaciente);
        $informes = Informe::where('idpeticion', $id)->get();
        $imagenes = Imagen::where('idpeticion',$id)->get();
        $nombrePdf='Patologia_'.$datosPaciente->paterno." ".$datosPaciente->materno." ".$datosPaciente->nombre;
        $enlace=route('patologiaPdf',['dato'=>$id]);
        //return response()->json($enlace);
        // Obtener el contenido del código QR
        QrCode::format('png')->size(450)->generate($enlace,'../public/qrcodes/'.$id.'.png');
        $codigoqr=$id;
        // Cargar la vista y pasar los datos
        $pdf = FacadePdf::loadView('peticion.patologiaPdf', compact('datosMedico','datosPaciente','informes','imagenes','codigoqr'))->setPaper('letter', 'portrait');
        // Descargar el PDF con un nombre específico
        $nombreArchivo = $nombrePdf. '.pdf';
        return $pdf->stream($nombreArchivo);
    }

    public function patologiaPdfUniversitario($id){
        $datosMedico=DB::table('medicos')->select('medicos.*')->get();
        $datosPaciente = Peticion::where('peticiones.id', $id)
        ->join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
        ->select('peticiones.*', 'pacientes.*')
        ->first();
        //return response()->json($datosPaciente);
        $informes = Informe::where('idpeticion', $id)->get();
        $imagenes = Imagen::where('idpeticion',$id)->get();
        $nombrePdf='Patologia_U_'.$datosPaciente->paterno." ".$datosPaciente->materno." ".$datosPaciente->nombre;
        $enlace=route('patologiaPdfUniversitario',['dato'=>$id]);
        // Obtener el contenido del código QR
        QrCode::format('png')->size(450)->generate($enlace,'../public/qrcodes/'.$id.'.png');
        $codigoqr=$id;
        // Cargar la vista y pasar los datos
        $pdf = FacadePdf::loadView('peticion.patologiaPdfUniversitario', compact('datosMedico','datosPaciente','informes','imagenes','codigoqr'))->setPaper('letter', 'portrait');
        // Descargar el PDF con un nombre específico
        $nombreArchivo = $nombrePdf. '.pdf';
        return $pdf->stream($nombreArchivo);
    }



    public function editarInformacion(Request $request, string $id)
    {
        
    $registro = $request->input('registro');
    $proveniencia = $request->input('proveniencia');
    $remitente = $request->input('remitente');
    $interpretacion = $request->input('interpretacion');
    $comentario = $request->input('comentario');
    $macroscopico = $request->input('macroscopico');
    $microscopico = $request->input('microscopico');

    try {
        $peticion = Peticion::where('id', $id)->firstOrFail();
        $peticion->registro = $registro;
        $peticion->proveniencia = $proveniencia;
        $peticion->remitente = $remitente;
        $peticion->save();
        $informes = Informe::where('idpeticion', $id)->get();
        $swInterpretacion = false;
        $swComentario = false;
        $swMacroscopico = false;
        $swMicroscopico = false;

        foreach ($informes as $informe) {
            switch ($informe->titulo) {
                case 'INTERPRETACIÓN':
                    $swInterpretacion = true;
                    $informe->descripcion = $interpretacion ?? ''; 
                    $informe->save();
                    break;
                case 'COMENTARIO':
                    $swComentario = true;
                    $informe->descripcion = $comentario ?? '';
                    $informe->save();
                    break;
                case 'MACROSCOPICO':
                    $swMacroscopico = true;
                    $informe->descripcion = $macroscopico ?? '';
                    $informe->save();
                    break;
                case 'MICROSCOPICO':
                    $swMicroscopico = true;
                    $informe->descripcion = $microscopico ?? '';
                    $informe->save();
                    break;
                default:
                    break;
            }
        }

        // Crear nuevos informes si no existen y tienen valor
        if (!$swInterpretacion && $interpretacion !== null) {
            $nuevoInforme = new Informe();
            $nuevoInforme->idpeticion = $id;
            $nuevoInforme->titulo = 'INTERPRETACIÓN';
            $nuevoInforme->descripcion = $interpretacion;
            $nuevoInforme->save();
        }

        if (!$swComentario && $comentario !== null) {
            $nuevoInforme = new Informe();
            $nuevoInforme->idpeticion = $id;
            $nuevoInforme->titulo = 'COMENTARIO';
            $nuevoInforme->descripcion = $comentario;
            $nuevoInforme->save();
        }

        if (!$swMacroscopico && $macroscopico !== null) {
            $nuevoInforme = new Informe();
            $nuevoInforme->idpeticion = $id;
            $nuevoInforme->titulo = 'MACROSCOPICO';
            $nuevoInforme->descripcion = $macroscopico;
            $nuevoInforme->save();
        }

        if (!$swMicroscopico && $microscopico !== null) {
            $nuevoInforme = new Informe();
            $nuevoInforme->idpeticion = $id;
            $nuevoInforme->titulo = 'MICROSCOPICO';
            $nuevoInforme->descripcion = $microscopico;
            $nuevoInforme->save();
        }

        // Manejar las imágenes
        $images = Imagen::where('idpeticion', $id)->get();
        $figura1 = $request->input('figura1');
        $figura2 = $request->input('figura2');
        
        if ($images->count() > 0) {
            // Actualizar imágenes existentes
            if ($request->hasFile('ruta1')) {
                $file1 = $request->file('ruta1');
                $filename1 = time() . '_' . $file1->getClientOriginalName();
                $file1->move(public_path('images'), $filename1);
                $images[0]->ruta = 'images/' . $filename1;
            }
            $images[0]->figura = $figura1;
            $images[0]->save();
        
            if ($request->hasFile('ruta2')) {
                $file2 = $request->file('ruta2');
                $filename2 = time() . '_' . $file2->getClientOriginalName();
                $file2->move(public_path('images'), $filename2);
        
                if (isset($images[1])) {
                    $images[1]->ruta = 'images/' . $filename2;
                    $images[1]->figura = $figura2;
                    $images[1]->save();
                } else {
                    $imagen = new Imagen();
                    $imagen->idpeticion = $id;
                    $imagen->figura = $figura2;
                    $imagen->ruta = 'images/' . $filename2;
                    $imagen->save();
                }
            } else if (isset($images[1])) {
                $images[1]->figura = $figura2;
                $images[1]->save();
            }
        } else {
            // Crear nuevas imágenes
            if ($request->hasFile('ruta1')) {
                $file1 = $request->file('ruta1');
                $filename1 = time() . '_' . $file1->getClientOriginalName();
                $file1->move(public_path('images'), $filename1);
        
                $imagen1 = new Imagen();
                $imagen1->idpeticion = $id;
                $imagen1->figura = $figura1;
                $imagen1->ruta = 'images/' . $filename1;
                $imagen1->save();
            }
        
            if ($request->hasFile('ruta2')) {
                $file2 = $request->file('ruta2');
                $filename2 = time() . '_' . $file2->getClientOriginalName();
                $file2->move(public_path('images'), $filename2);
        
                $imagen2 = new Imagen();
                $imagen2->idpeticion = $id;
                $imagen2->figura = $figura2;
                $imagen2->ruta = 'images/' . $filename2;
                $imagen2->save();
            }
        }
        return response()->json(['message' => 'Informes actualizados correctamente'], 200);

    } catch (\Exception $e) {
        return response()->json(['error' => 'Error al editar informes: ' . $e->getMessage()], 500);
    }
}
    public function exportar()
    {
        return Excel::download(new Pacientes, 'nombre-del-archivo.xlsx');
    }

    public function informePacientes(){
        return view('peticion.informePaciente');
    }

    public function obtenerInformePacientes(){
        $solicitud = DB::select('SELECT peticiones.id,peticiones.registro, CONCAT(pacientes.paterno," ",pacientes.materno," ",pacientes.nombre) AS nombreCompleto,
                                    peticiones.proveniencia,peticiones.remitente,pacientes.idinstitucion,institucion.nombreInstituto,peticiones.tipo,peticiones.estado
                                    FROM peticiones
                                    JOIN pacientes ON pacientes.id=peticiones.idpaciente
                                    left JOIN institucion ON institucion.id=pacientes.idinstitucion 
                                    ORDER BY peticiones.visita desc');
        return response()->json($solicitud);
    }

    public function obtenerEstadisticaInformes(Request $request){
        $fechaIni = $request->input('fechaInicial');
        $fechaFin = $request->input('fechaFinal');
        $cantidad=Peticion::count();
        $cantidadUniversidad = Peticion::join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
                                ->where('pacientes.idinstitucion', 1)
                                ->whereBetween('peticiones.visita', [$fechaIni, $fechaFin])
                                ->count();

        $cantidadParticular = Peticion::join('pacientes', 'pacientes.id', '=', 'peticiones.idpaciente')
                    ->where('pacientes.idinstitucion', 4)
                    ->whereBetween('peticiones.visita', [$fechaIni, $fechaFin])
                    ->count();
        $resultados = [
            'cantidadParticular' => $cantidadParticular,
            'cantidadUniversidad' => $cantidadUniversidad,
            'cantidad' => $cantidad,
        ];
        return response()->json($resultados);
    }
    
    public function validarInformacion(string $id){
        $peticion = Peticion::where('id', $id)->firstOrFail();
        $peticion->estado = 1;
        $peticion->validado = now();
        $peticion->save();
        return response()->json("validado correctamente");
    }

    public function cantidadHistorial(string $id){
        $cantidad = Peticion::select(DB::raw('COUNT(tipo) as cantidad, tipo'))
        ->where('idpaciente',$id)
        ->groupBy('tipo')
        ->get();

                return response()->json($cantidad);
    }
}

