<?php

use App\Http\Controllers\FertilidadController;
use App\Http\Controllers\GinecologiaController;
use App\Http\Controllers\InstitucionController;
use App\Http\Controllers\MedicoController;
use App\Http\Controllers\ObstetriciaController;
use App\Http\Controllers\PacienteController;
use App\Http\Controllers\PerfilController;
use App\Http\Controllers\PeticionController;
use App\Http\Controllers\TipoPeticionController;
use App\Http\Controllers\UsuarioController;
use App\Http\Controllers\InformeInmunoController;
use App\Http\Controllers\InmunoController;
use App\Http\Controllers\ResultadoCitologicoController;
use App\Http\Livewire\Cities;
use App\Http\Livewire\Countries;
use App\Http\Livewire\Currencies;
use App\Http\Livewire\Dashboard;
use App\Http\Livewire\DocumentTypes;
use App\Http\Livewire\Roles;
use App\Http\Livewire\States;
use App\Http\Livewire\Users;
use App\Http\Livewire\Profiles;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    return view('auth.login');
});

Route::middleware('auth')->group(function () {
    Route::get('/profiles', Profiles::class)->name('profiles');
});

Route::middleware(['auth', 'verified'])->group(function () {
    Route::get('/dashboard', Dashboard::class)->name('dashboard');
    Route::get('/city', Cities::class)->name('cities');
    Route::get('/country', Countries::class)->name('countries');
    Route::get('/currency', Currencies::class)->name('currencies');
    Route::get('/document', DocumentTypes::class)->name('document_types');
    Route::get('/role', Roles::class)->name('roles');
    Route::get('/state', States::class)->name('states');
    Route::get('/user', Users::class)->name('users');
    Route::resource('usuarios', UsuarioController::class);
    Route::resource('pacientes', PacienteController::class);
    Route::resource('medicos', MedicoController::class);
    Route::resource('instituciones', InstitucionController::class);
    Route::resource('tipopeticiones', TipoPeticionController::class);
    Route::resource('peticiones', PeticionController::class);
    Route::resource('perfiles', PerfilController::class);
    Route::resource('informeInmunos', InformeInmunoController::class);
    Route::resource('inmunos', InmunoController::class);
    Route::resource('citologicos', ResultadoCitologicoController::class);
    Route::resource('ginecologias', GinecologiaController::class);

    Route::resource('obstetricia', ObstetriciaController::class);
    Route::resource('fertilidad', FertilidadController::class);
    Route::post('editarFertilidad/{peticion}', [FertilidadController::class, 'editarFertilidad']);
    //ruta para eliminarPerfilHormonal
    Route::post('eliminarPerfilHormonal/{perfilHormonal}', [FertilidadController::class, 'eliminarPerfilHormonal']);
    //ruta para actualizarPerfilHormonal
    Route::post('actualizarPerfilHormonal/{perfilHormonal}', [FertilidadController::class, 'actualizarPerfilHormonal']);

    ///ruta para actualizarExamen
    Route::post('actualizarExamen/{examen}', [FertilidadController::class, 'actualizarExamen']);
    //ruta para eliminarExamen
    Route::post('eliminarExamen/{examen}', [FertilidadController::class, 'eliminarExamen']);
    Route::post('/perfil/actualizar', [PerfilController::class, 'actualizar'])->name('perfil.actualizar');
    Route::get('/informaciones', [PeticionController::class, 'informaciones'])->name('informaciones');
    Route::get('/informacionGinecologia', [PeticionController::class, 'informacionGinecologia'])->name('informacionGinecologia');
    Route::get('/crearPacienteGinecologia', [PacienteController::class, 'crearGinecologia'])->name('pacientes.crearPacienteGine');
    Route::post('/guardarInformacion', [PeticionController::class, 'guardarInformacion'])->name('guardarInformacion');
    Route::get('/obtenerusuario', [Users::class, 'obtenerUsuario']);
    Route::post('/datosusuario', [UsuarioController::class, 'datosusuario']);
    Route::post('/actualizarusuario', [UsuarioController::class, 'actualizarusuario']);
    Route::get('/obtenerpaciente', [PacienteController::class, 'obtenerPaciente']);
    Route::get('/obtenermedico', [MedicoController::class, 'obtenerMedico']);
    Route::get('/obtenerHistorial/{dato}', [PeticionController::class, 'obtenerHistorial']);
    Route::get('/obtenerHistorialInmuno/{dato}', [InmunoController::class, 'obtenerHistorialInmuno']);
    Route::get('/obtenerHistorialGinecologia/{dato}', [GinecologiaController::class, 'obtenerHistorialGinecologia']);
    Route::get('/obtenerHistorialObstetricia/{dato}', [ObstetriciaController::class, 'obtenerHistorialObstetricia']);
    //ruta para obtenerHistorialFertilidad
    Route::get('/obtenerHistorialFertilidad/{dato}', [FertilidadController::class, 'obtenerHistorialFertilidad']);
    Route::get('/obtenerHistorialCito/{dato}', [ResultadoCitologicoController::class, 'obtenerHistorialCito']);
    Route::get('/obtenerHistorialEstado/{dato}', [GinecologiaController::class, 'obtenerHistorialEstado']);
    Route::get('/cantidadHistorial/{dato}', [PeticionController::class, 'cantidadHistorial']);
    Route::get('/obtenerinstitucion', [InstitucionController::class, 'obtenerInstitucion']);
    Route::get('/obtenertipopeticiones', [TipoPeticionController::class, 'obtenerTipoPeticion']);
    Route::get('/busquedaPaciente', [PeticionController::class, 'busquedaPaciente']);
    Route::get('/resultado/{datos}', [PeticionController::class, 'resultado'])->name('resultado');
    Route::get('/obtenerPeticiones', [PeticionController::class, 'obtenerPeticiones']);
    Route::get('/patologiaPdf/{dato}', [PeticionController::class, 'patologiaPdf'])->name('patologiaPdf');
    Route::get('/patologiaPdfUniversitario/{dato}', [PeticionController::class, 'patologiaPdfUniversitario'])->name('patologiaPdfUniversitario');
    Route::get('/filtrarPaciente', [PeticionController::class, 'filtrarPacientePorParametro']);
    Route::get('/filtrarPaciente/{dato}', [PeticionController::class, 'filtrarPaciente']);
    Route::get('/filtrarPacienteCodigo/{dato}', [PeticionController::class, 'filtrarPacienteCodigo']);
    Route::get('/filtrarPacienteCi/{dato}', [PeticionController::class, 'filtrarPacienteCi']);
    Route::get('/filtrarPacienteDiagnostico/{dato}', [PeticionController::class, 'filtrarPacienteDiagnostico']);
    Route::get('/filtrarPacienteNombre', [PeticionController::class, 'filtrarPacienteNombre']);
    Route::get('/filtrarPacienteMaterno', [PeticionController::class, 'filtrarPacienteMaterno']);
    Route::get('/filtrarPacienteSexo/{dato}', [PeticionController::class, 'filtrarPacienteSexo']);
    Route::get('/filtrarPacienteEdad/{dato}', [PeticionController::class, 'filtrarPacienteEdad']);
    Route::get('/crearInformacion/{dato}', [PeticionController::class, 'crearInformacion'])->name('crearInformacion');
    Route::get('/historialInformacion/{dato}', [PeticionController::class, 'historialInformacion'])->name('historialInformacion');
    Route::get('/historialInformacionInmuno/{dato}', [InmunoController::class, 'historialInformacionInmuno'])->name('historialInformacionInmuno');
    Route::get('/historialInformacionGinecologia/{dato}', [GinecologiaController::class, 'historialInformacionGinecologia'])->name('historialInformacionGinecologia');
    Route::get('/historialInformacionObstetricia/{dato}', [ObstetriciaController::class, 'historialInformacionObstetricia'])->name('historialInformacionObstetricia');
    Route::post('/editarInformacion/{dato}', [PeticionController::class, 'editarInformacion']);
Route::get('/informePacientes', [PeticionController::class, 'informePacientes'])->name('informePacientes');
Route::get('/obtenerInformePacientes', [PeticionController::class, 'obtenerInformePacientes']);
Route::get('/obtenerEstadisticaInformes', [PeticionController::class, 'obtenerEstadisticaInformes']);
Route::get('/crearInmuno/{dato}', [InmunoController::class, 'crearInmuno'])->name('crearInmuno');
Route::get('/crearCitologia/{dato}', [ResultadoCitologicoController::class, 'crearCitologia'])->name('crearCitologia');
Route::get('/crearGinecologia/{dato}', [GinecologiaController::class, 'crearGinecologia'])->name('crearGinecologia');
Route::post('/editarGinecologia/{dato}', [GinecologiaController::class, 'editarGinecologia']);
Route::post('/editarObstetricia/{dato}', [ObstetriciaController::class, 'editarObstetricia']);
Route::get('/historialCitologia/{dato}', [ResultadoCitologicoController::class, 'historialCitologia'])->name('historialCitologia');
Route::get('/historialInmuno/{dato}', [InmunoController::class, 'historialInmuno'])->name('historialInmuno');
Route::get('/historialCito/{dato}', [ResultadoCitologicoController::class, 'historialCito'])->name('historialCito');
Route::get('/historialInformacionFertilidad/{dato}', [FertilidadController::class, 'historialInformacionFertilidad'])->name('historialInformacionFertilidad');
Route::post('/editarInmuno/{dato}', [InmunoController::class, 'editarInmuno']);
Route::post('/validarInformacion/{dato}', [PeticionController::class, 'validarInformacion']);
Route::get('/obtenerHistorialDx/{dato}', [PacienteController::class, 'obtenerHistorialDx'])->name('obtenerHistorialDx');
Route::get('/crearObstetricia/{id}', [ObstetriciaController::class, 'crearObstetricia'])->name('crearObstetricia');
Route::get('/crearFertilidad/{id}', [FertilidadController::class, 'crearFertilidad'])->name('crearFertilidad');
Route::get('/exportar', [PeticionController::class, 'exportar'])->name('exportar');
});
//de Fertilidad


Route::get('/inmunoPdf/{dato}', [InmunoController::class, 'inmunoPdf'])->name('inmunoPdf');
Route::get('/ginecologiaPdf/{dato}', [GinecologiaController::class, 'ginecologiaPdf'])->name('ginecologiaPdf');
Route::get('/citologiaPdf/{dato}', [ResultadoCitologicoController::class, 'citologiaPdf'])->name('citologiaPdf');
Route::get('/inmunoPdfUniversitario/{dato}', [InmunoController::class, 'inmunoPdfUniversitario'])->name('inmunoPdfUniversitario');
Route::get('/citoPdfUniversitario/{dato}', [ResultadoCitologicoController::class, 'citoPdfUniversitario'])->name('citoPdfUniversitario');
Route::get('/obstetriciaPdf/{id}', [ObstetriciaController::class, 'obstetriciaPdf'])->name('obstetriciaPdf');
Route::get('/fertilidadPdf/{id}', [FertilidadController::class, 'fertilidadPdf'])->name('fertilidadPdf');
/* Para obstetricia */
//crar
/* Para fertilidad */

require __DIR__ . '/auth.php';
